==> atmc-http-0.0.2.0048-sources.jar: com/digiwin/athena/atmc/http/restful/abt/impl/AbtServiceImpl.java <==
package com.digiwin.athena.atmc.http.restful.abt.impl;

import com.digiwin.athena.appcore.domain.BaseResultDTO;
import com.digiwin.athena.atmc.application.configuration.EnvProperties;
import com.digiwin.athena.atmc.http.constant.AbtApiConstant;
import com.digiwin.athena.atmc.http.restful.HttpAssistantServiceImpl;
import com.digiwin.athena.atmc.http.restful.abt.AbtService;
import com.digiwin.athena.atmc.http.restful.abt.model.NoticeAbtRepairDto;
import com.digiwin.athena.atmc.http.restful.abt.model.RefreshCardMessageDTO;
import com.fasterxml.jackson.core.type.TypeReference;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.core.ParameterizedTypeReference;
import org.springframework.http.*;
import org.springframework.stereotype.Service;
import org.springframework.web.client.RestTemplate;

/**
 * AbtServiceImpl Description
 *
 * @author majianfu
 * @date 2023/4/7
 * @since
 */
@Slf4j
@Service
public class AbtServiceImpl implements AbtService {

    @Autowired
    private EnvProperties envProperties;

    @Autowired
    private HttpAssistantServiceImpl httpAssistantService;

    @Autowired
    private RestTemplate restTemplate;

    /**
     * {@inheritDoc}
     */
    @Override
    public void createRefreshCardMessageJob(RefreshCardMessageDTO refreshCardMessageDTO) {
        String url = envProperties.getAbtUri() + AbtApiConstant.REFRESH_CARD_MESSAGE_JOB_CREATE_IF_ABSENT;

        HttpHeaders headers = new HttpHeaders();
        headers.setContentType(MediaType.APPLICATION_JSON);

        log.info("create refresh card message job{}, {}", refreshCardMessageDTO.getId(), refreshCardMessageDTO);
        Boolean success = httpAssistantService.post(new TypeReference<Boolean>() {
        }, url, headers, refreshCardMessageDTO);
        log.info("create refresh card message job{}, {}, ret{}", refreshCardMessageDTO.getId(), refreshCardMessageDTO, success);
    }
    @Override
    public void noticeRepairApcData(NoticeAbtRepairDto dto) {

        log.info("AbtServiceImpl.noticeRepairApcData{}", dto);
        String url = envProperties.getAbtUri() + AbtApiConstant.NOTICE_REPAIR_APC_DATA;
        HttpHeaders headers = new HttpHeaders();
        headers.setContentType(MediaType.APPLICATION_JSON);
//        headers.add(GlobalConstant.IAM_USER_TOKEN, user.getToken());

        HttpEntity httpEntity = new HttpEntity(dto, headers);
        try {
            ResponseEntity<BaseResultDTO> respEntity = restTemplate.exchange(url, HttpMethod.POST, httpEntity, new ParameterizedTypeReference<BaseResultDTO>() {
            });
            if (respEntity.getStatusCode().value() != org.apache.http.HttpStatus.SC_OK || !respEntity.getBody().isOK()) {
                log.error("Failed to request abt to noticeRepairApcData ，statusCode: {}, responseBody: {}.", respEntity.getStatusCode().value(), respEntity.getBody());
            }
        } catch (Exception ex) {
            log.error("Failed to request abt to noticeRepairApcData，error: {}.", ex);
        }
    }
}

==> atmc-http-0.0.2.0054-sources.jar: com/digiwin/athena/atmc/http/restful/abt/impl/AbtServiceImpl.java <==
package com.digiwin.athena.atmc.http.restful.abt.impl;

import com.digiwin.athena.appcore.domain.BaseResultDTO;
import com.digiwin.athena.appcore.util.JsonUtils;
import com.digiwin.athena.atmc.application.configuration.EnvProperties;
import com.digiwin.athena.atmc.http.constant.AbtApiConstant;
import com.digiwin.athena.atmc.http.restful.HttpAssistantServiceImpl;
import com.digiwin.athena.atmc.http.restful.abt.AbtService;
import com.digiwin.athena.atmc.http.restful.abt.model.NoticeAbtRepairDto;
import com.digiwin.athena.atmc.http.restful.abt.model.RefreshCardMessageDTO;
import com.fasterxml.jackson.core.type.TypeReference;
import com.jugg.agile.biz.digiwin.config.biz.DwBizConfig;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.core.ParameterizedTypeReference;
import org.springframework.http.*;
import org.springframework.stereotype.Service;
import org.springframework.web.client.RestTemplate;

import javax.annotation.PostConstruct;
import java.util.Map;
import java.util.Objects;

/**
 * AbtServiceImpl Description
 *
 * @author majianfu
 * @date 2023/4/7
 * @since
 */
@Slf4j
@Service
public class AbtServiceImpl implements AbtService {

    @Autowired
    private EnvProperties envProperties;

    @Autowired
    private HttpAssistantServiceImpl httpAssistantService;

    @Autowired
    private RestTemplate restTemplate;

    /**
     * {@inheritDoc}
     */
    @Override
    public void createRefreshCardMessageJob(RefreshCardMessageDTO refreshCardMessageDTO) {
        String url = getAbtUri() + AbtApiConstant.REFRESH_CARD_MESSAGE_JOB_CREATE_IF_ABSENT;

        HttpHeaders headers = new HttpHeaders();
        headers.setContentType(MediaType.APPLICATION_JSON);

        log.info("create refresh card message job{}, {}", refreshCardMessageDTO.getId(), refreshCardMessageDTO);
        Boolean success = httpAssistantService.post(new TypeReference<Boolean>() {
        }, url, headers, refreshCardMessageDTO);
        log.info("create refresh card message job{}, {}, ret{}", refreshCardMessageDTO.getId(), refreshCardMessageDTO, success);
    }

    private String getAbtUri() {
        return DwBizConfig.AaskDomainConfig.Sai.getAbtUri();

    }

    @Override
    public void noticeRepairApcData(NoticeAbtRepairDto dto) {

        log.info("AbtServiceImpl.noticeRepairApcData{}", dto);
        String url = getAbtUri() + AbtApiConstant.NOTICE_REPAIR_APC_DATA;
        HttpHeaders headers = new HttpHeaders();
        headers.setContentType(MediaType.APPLICATION_JSON);
//        headers.add(GlobalConstant.IAM_USER_TOKEN, user.getToken());

        HttpEntity httpEntity = new HttpEntity(dto, headers);
        try {
            ResponseEntity<BaseResultDTO> respEntity = restTemplate.exchange(url, HttpMethod.POST, httpEntity, new ParameterizedTypeReference<BaseResultDTO>() {
            });
            if (respEntity.getStatusCode().value() != org.apache.http.HttpStatus.SC_OK || !respEntity.getBody().isOK()) {
                log.error("Failed to request abt to noticeRepairApcData ，statusCode: {}, responseBody: {}.", respEntity.getStatusCode().value(), respEntity.getBody());
            }
        } catch (Exception ex) {
            log.error("Failed to request abt to noticeRepairApcData，error: {}.", ex);
        }
    }

    /**
     * 历史项目任务发起异步导出功能  调用abt实现
     * @param paramMap
     * @return
     */
    @Override
    public Boolean historyStartDownload(Map<String, Object> paramMap) {
        String url = getAbtUri() + AbtApiConstant.HISTORY_START_DOWNLOAD;

        HttpHeaders headers = new HttpHeaders();
        headers.setContentType(MediaType.APPLICATION_JSON);

        log.info("do historyStartDownload,params:{}", JsonUtils.objectToString(paramMap));
        Boolean success = httpAssistantService.post(new TypeReference<Boolean>() {
        }, url, headers, paramMap);
        return success;
    }
}
